@@ -26,6 +26,7 @@
 
     * [User Pool Authorizer](#user-pool-authorizer)
   * [Lambda Authorizers](#lambda-authorizers)
+  * [IAM Authorizers](#iam-authorizers)
 * [WebSocket APIs](#websocket-apis)
 
   * [Lambda Authorizer](#lambda-authorizer)
@@ -205,6 +206,31 @@ api.add_routes(
 )
 ```
 
+### IAM Authorizers
+
+API Gateway supports IAM via the included `HttpIamAuthorizer` and grant syntax:
+
+```python
+from aws_cdk.aws_apigatewayv2_authorizers import HttpIamAuthorizer
+from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
+
+# principal is of type AnyPrincipal
+
+
+authorizer = HttpIamAuthorizer()
+
+http_api = apigwv2.HttpApi(self, "HttpApi",
+    default_authorizer=authorizer
+)
+
+routes = http_api.add_routes(
+    integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
+    path="/books/{book}"
+)
+
+routes[0].grant_invoke(principal)
+```
+
 ## WebSocket APIs
 
 You can set an authorizer to your WebSocket API's `$connect` route to control access to your API.
@@ -255,6 +281,64 @@ import aws_cdk.core
 import constructs
 
 
+@jsii.implements(aws_cdk.aws_apigatewayv2.IHttpRouteAuthorizer)
+class HttpIamAuthorizer(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-apigatewayv2-authorizers.HttpIamAuthorizer",
+):
+    '''(experimental) Authorize HTTP API Routes with IAM.
+
+    :stability: experimental
+
+    Example::
+
+        from aws_cdk.aws_apigatewayv2_authorizers import HttpIamAuthorizer
+        from aws_cdk.aws_apigatewayv2_integrations import HttpUrlIntegration
+        
+        # principal is of type AnyPrincipal
+        
+        
+        authorizer = HttpIamAuthorizer()
+        
+        http_api = apigwv2.HttpApi(self, "HttpApi",
+            default_authorizer=authorizer
+        )
+        
+        routes = http_api.add_routes(
+            integration=HttpUrlIntegration("BooksIntegration", "https://get-books-proxy.myproxy.internal"),
+            path="/books/{book}"
+        )
+        
+        routes[0].grant_invoke(principal)
+    '''
+
+    def __init__(self) -> None:
+        '''
+        :stability: experimental
+        '''
+        jsii.create(self.__class__, self, [])
+
+    @jsii.member(jsii_name="bind")
+    def bind(
+        self,
+        *,
+        route: aws_cdk.aws_apigatewayv2.IHttpRoute,
+        scope: constructs.Construct,
+    ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
+        '''(experimental) (experimental) Bind this authorizer to a specified Http route.
+
+        :param route: (experimental) The route to which the authorizer is being bound.
+        :param scope: (experimental) The scope for any constructs created as part of the bind.
+
+        :stability: experimental
+        '''
+        _options = aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerBindOptions(
+            route=route, scope=scope
+        )
+
+        return typing.cast(aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig, jsii.invoke(self, "bind", [_options]))
+
+
 @jsii.implements(aws_cdk.aws_apigatewayv2.IHttpRouteAuthorizer)
 class HttpJwtAuthorizer(
     metaclass=jsii.JSIIMeta,
@@ -997,6 +1081,7 @@ class WebSocketLambdaAuthorizerProps:
 
 
 __all__ = [
+    "HttpIamAuthorizer",
     "HttpJwtAuthorizer",
     "HttpJwtAuthorizerProps",
     "HttpLambdaAuthorizer",
